article

package
v0.4.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 29, 2023 License: GPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Create

func Create(c *gin.Context)

Create create article (published or draft) handler

func Delete

func Delete(c *gin.Context)

Delete delete article handler

func Get

func Get(c *gin.Context)

Get get article handler (article info in detail)

func List

func List(c *gin.Context)

List return the article list in page

func Update

func Update(c *gin.Context)

Update update article Delete and restore article are also in this function and it depends on the 'status'

Types

This section is empty.

Jump to